<?php
/**
 * Commercioo checkout.
 *
 * @author Commercioo Team
 * @package Commercioo
 */

namespace Commercioo;

if ( ! defined( 'WPINC' ) ) {
	exit;
}

if ( ! class_exists( 'Commercioo\Checkout' ) ) {

	/**
	 * Class Checkout
	 */
	class Checkout {

		/**
		 * Default fields
		 * 
		 * @var array
		 */
		private $default_fields = array();

		/**
		 * Class instance
		 * 
		 */
		private static $instance;

		/**
		 * Order constructor.
		 *
		 * @param int $order_id order id.
		 */
		public function __construct() {
		}

		/**
		 * Get class instance
		 * 
		 * @return Checkout Class instance.
		 */
		public static function get_instance() {
			if ( ! isset( self::$instance ) ) {
				self::$instance = new Checkout();
			}
			return self::$instance;
		}
        /**
         * Set default fields
         */
		public function set_default_fields(){
            $field = apply_filters("commercioo_ongkir_checkout_default_fields",$this->default_fields());
            $this->default_fields = $field;
        }
		/**
		 * Defined default fields
		 */
		public function default_fields() {
			global $comm_country;
            $default_fields = array(
                    'billing' => array(
                        'first_name'    => array(
                            'label'     => __( 'First Name', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => true,
                            'priority'  => 10,
                            'attrs'      => array(
                                'minlength' => 2
                            )
                        ),
                        'last_name'     => array(
                            'label'     => __( 'Last Name', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 20
                        ),
                        'email'         => array(
                            'label'     => __( 'Email Address', 'commercioo' ),
                            'type'      => 'email',
                            'required'  => true,
                            'priority'  => 30
                        ),
                        'phone'         => array(
                            'label'     => __( 'Phone Number', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => true,
                            'priority'  => 40,
                            'attrs'      => array(
                                'minlength' => 5
                            )
                        ),
                        'company'       => array(
                            'label'     => __( 'Company', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 50
                        ),
                        'country'       => array(
                            'label'     => __( 'Country', 'commercioo' ),
                            'type'      => 'select',
                            'options'	=> $comm_country,
                            'required'  => false,
                            'priority'  => 60
                        ),
                        'state'         => array(
                            'label'     => __( 'State / Province', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 70
                        ),
                        'city'          => array(
                            'label'     => __( 'Town / City', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 80
                        ),
                        'zip'           => array(
                            'label'     => __( 'Postcode / ZIP', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 90
                        ),
                        'street_address' => array(
                            'label'     => __( 'Street Address', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 100
                        ),
                    ),
                    'shipping' => array(
                        'first_name'    => array(
                            'label'     => __( 'First Name', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => true,
                            'priority'  => 10,
                            'attrs'      => array(
                                'minlength' => 2
                            )
                        ),
                        'last_name'     => array(
                            'label'     => __( 'Last Name', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 20
                        ),
                        'email'         => array(
                            'label'     => __( 'Email Address', 'commercioo' ),
                            'type'      => 'email',
                            'required'  => true,
                            'priority'  => 30
                        ),
                        'phone'         => array(
                            'label'     => __( 'Phone Number', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => true,
                            'priority'  => 40,
                            'attrs'      => array(
                                'minlength' => 5
                            )
                        ),
                        'company'       => array(
                            'label'     => __( 'Company', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 50
                        ),
                        'country'       => array(
                            'label'     => __( 'Country', 'commercioo' ),
                            'type'      => 'select',
                            'options'	=> $comm_country,
                            'required'  => false,
                            'priority'  => 60
                        ),
                        'state'         => array(
                            'label'     => __( 'State / Province', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 70
                        ),
                        'city'          => array(
                            'label'     => __( 'Town / City', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 80
                        ),
                        'zip'           => array(
                            'label'     => __( 'Postcode / ZIP', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 90
                        ),
                        'street_address' => array(
                            'label'     => __( 'Street Address', 'commercioo' ),
                            'type'      => 'text',
                            'required'  => false,
                            'priority'  => 100
                        ),
                    ),
                    'ship_to_different_address' => array(
                        'label'     => __( 'SHIP TO DIFFERENT ADDRESS', 'commercioo' ),
                        'type'      => 'checkbox',
                        'required'  => false,
                        'attrs'      => array(
                            'class' => 'checkbox-shipping',
                            'id'    => 'checkbox_ship_different'
                        )
                    ),
                    'order_notes' => array(
                        'label'     => __( 'ORDER NOTES', 'commercioo' ),
                        'type'      => 'textarea',
                        'required'  => false,
                        'attrs'      => array(
                            'rows' => 3
                        )
                    )
                );
            return $default_fields;
		}

		/**
		 * Get default fields
		 * 
		 * @param  boolean|string $index Default index.
		 * @return array                 Field default.
		 */
		public function get_default_fields( $index = false ) {
            $this->default_fields();
            $this->set_default_fields();
			if ( $index && isset( $this->default_fields[ $index ] ) ) {
				if ( 'billing' === $index || 'shipping' === $index ) {
					uasort( $this->default_fields[ $index ], array( $this, 'sort_field_by_priority' ) );
				}
				return $this->default_fields[ $index ];
			}
			return $this->default_fields;
		}

		/**
		 * Get billing fields
		 * 
		 * @return array Active billing fields.
		 */
		public function get_billing_fields() {
			$fields = array();

			// sort field based on priority.
			uasort( $this->default_fields['billing'], array( $this, 'sort_field_by_priority' ) );

			// get settings.
			$order_forms = get_option( 'comm_order_forms_settings', array() );
			$billing     = isset( $order_forms['billing_address'] ) ? $order_forms['billing_address'] : array();

			foreach ( $this->default_fields['billing'] as $key => $field ) {
				$visibility = isset( $billing["billing_{$key}_visibility"] ) ? $billing["billing_{$key}_visibility"] : 'required';
				if ( $field['required'] || 'hidden' !== $visibility ) {
					$fields[ $key ] = $field;

					// override label from setting.
					if ( isset( $billing["billing_{$key}"] ) && ! empty( $billing["billing_{$key}"] ) ) {
						$fields[ $key ]['label'] = $billing["billing_{$key}"];
					}

					// override required from setting.
					$fields[ $key ]['required'] = $field['required'] || 'required' === $visibility;
				}
			}

			return $fields;
		}

		/**
		 * Get shipping fields
		 * 
		 * @return array Active shipping fields.
		 */
		public function get_shipping_fields() {
			$fields = array();

			// sort field based on priority.
			uasort( $this->default_fields['shipping'], array( $this, 'sort_field_by_priority' ) );

			// get settings.
			$order_forms = get_option( 'comm_order_forms_settings', array() );
			$billing     = isset( $order_forms['billing_address'] ) ? $order_forms['billing_address'] : array();

			foreach ( $this->default_fields['shipping'] as $key => $field ) {
				$visibility = isset( $billing["billing_{$key}_visibility"] ) ? $billing["billing_{$key}_visibility"] : 'required';
				if ( $field['required'] || 'hidden' !== $visibility ) {
					$fields[ $key ] = $field;

					// override label from setting.
					if ( isset( $billing["billing_{$key}"] ) && ! empty( $billing["billing_{$key}"] ) ) {
						$fields[ $key ]['label'] = $billing["billing_{$key}"];
					}

					// override required from setting.
					$fields[ $key ]['required'] = $field['required'] || 'required' === $visibility;
				}
			}
			
			return $fields;
		}

		/**
		 * Get order note field
		 * 
		 * @return array Order note field.
		 */
		public function get_order_note_field() {
			$field = $this->default_fields['order_notes'];

			// get settings.
			$order_forms = get_option( 'comm_order_forms_settings', array() );

			$visibility = isset( $order_forms["order_note_visibility"] ) ? $order_forms["order_note_visibility"] : 'optional';
			if ( $field['required'] || 'hidden' !== $visibility ) {
				// override label from setting.
				if ( isset( $order_forms["order_note_label"] ) && ! empty( $order_forms["order_note_label"] ) ) {
					$field['label'] = $order_forms["order_note_label"];
				}

				// override required from setting.
				$field['required'] = $field['required'] || 'required' === $visibility;
			} else {
				return false;
			}
			
			return $field;
		}

		/**
		 * Render the field
		 * 
		 * @param  array  $args  Field arguments.
		 * @param  string $name  Field name.
		 * @param  string $value Field value.
		 */
		public static function render_field( $args, $name = '', $value = '' ) {
			switch ( $args['type'] ) {
				case 'text':
				case 'email':
				case 'url':
				case 'number':
				case 'password':
					echo '<input type="' . esc_attr($args['type']) . '" name="' . esc_attr( $name ) . '" placeholder="' . esc_attr( $args['label'] ) . '" ';
					if ( isset( $args['attrs'] ) && is_array( $args['attrs'] ) ) {
						foreach ( $args['attrs'] as $attr_key => $attr_value ) {
							echo wp_kses_post($attr_key . '="' . esc_attr( $attr_value ) . '" ');
						}
					}
					if ( $value ) {
						echo wp_kses_post('value="' . esc_attr( $value ) . '" ');
					} elseif ( isset( $args['value'] ) ) {
						echo wp_kses_post('value="' . esc_attr( $args['value'] ) . '" ');
					}
					if ( $args['required'] ) {
						echo wp_kses_post('required ');
					}
					echo '/>';
					break;

				case 'textarea':
					echo '<textarea name="' . esc_attr( $name ) . '" placeholder="' . esc_attr( $args['label'] ) . '" ';
					if ( isset( $args['attrs'] ) && is_array( $args['attrs'] ) ) {
						foreach ( $args['attrs'] as $attr_key => $attr_value ) {
							echo wp_kses_post($attr_key . '="' . esc_attr( $attr_value ) . '" ');
						}
					}
					if ( $args['required'] ) {
						echo wp_kses_post('required ');
					}
					echo '>';
					if ( $value ) {
						echo 'value="' . esc_textarea( $value ) . '" ';
					} elseif ( isset( $args['value'] ) ) {
						echo 'value="' . esc_textarea( $args['value'] ) . '" ';
					}
					echo '</textarea>';
					break;

				case 'select':
					echo '<select name="' . esc_attr( $name ) . '" ';
					if ( isset( $args['attrs'] ) && is_array( $args['attrs'] ) ) {
						foreach ( $args['attrs'] as $attr_key => $attr_value ) {
							echo wp_kses_post($attr_key . '="' . esc_attr( $attr_value ) . '" ');
						}
					}
					if ( $args['required'] ) {
						echo 'required ';
					}
					echo '>';
					if ( empty( $value ) && isset( $args['value'] ) ) {
						$value = $args['value'];
					}
					if ( isset( $args['options'] ) && is_array( $args['options'] ) ) {
						foreach ( $args['options'] as $option_key => $option_label ) {
						    ?>
							<option value="<?php echo esc_attr( $option_key );?>"  <?php selected( $option_key, $value );?>><?php echo esc_html( $option_label );?></option>
                       <?php
						}
					}
					echo '</select>';
					break;
			}
		}

		/**
		 * Submit actions for checkout form.
		 */
		public static function do_checkout() {
			global $comm_options;

			// check nonce
			check_admin_referer( 'GwJpuj_HVaV604dHE', '_comm_checkout_nonce' );

			/**
			 * Checkout validation
			 * Mainly now used by SaaS to limit the checkout number per month
			 */
			do_action( 'commercioo_validate_checkout' );

			// validate fields
			self::validate_checkout_data();

			/**
			 * Billing and shipping addresses
			 * ba as billing_address
			 * sa as shipping_address
			 */
			$ba = array();
			if(isset($_POST['billing_address']) && is_array($_POST['billing_address'])){
                $ba =sanitize_post($_POST['billing_address']);
            }
            $sa = array();
            if(isset($_POST['shipping_address']) && is_array($_POST['shipping_address'])){
                $sa =sanitize_post($_POST['shipping_address']);
            }
			// get billing address
			$billing_address = array(
				'billing_first_name' => sanitize_text_field(isset($ba['billing_first_name']) ? $ba['billing_first_name'] : null),
				'billing_last_name' => sanitize_text_field(isset($ba['billing_last_name']) ? $ba['billing_last_name'] : null),
				'billing_email' => sanitize_email(isset($ba['billing_email']) ? $ba['billing_email'] : null),
				'billing_phone' => sanitize_text_field(isset($ba['billing_phone']) ? $ba['billing_phone'] : null),
				'billing_company' => sanitize_text_field(isset($ba['billing_company']) ? $ba['billing_company'] : null),
				'billing_country' => sanitize_text_field(isset($ba['billing_country']) ? $ba['billing_country'] : null),
				'billing_street_address' => sanitize_text_field(isset($ba['billing_street_address']) ? $ba['billing_street_address'] : null),
				'billing_city' => sanitize_text_field(isset($ba['billing_city']) ? $ba['billing_city'] : null),
				'billing_state' => sanitize_text_field(isset($ba['billing_state']) ? $ba['billing_state'] : null),
				'billing_zip' => sanitize_text_field(isset($ba['billing_zip']) ? $ba['billing_zip'] : null),
			);
            $shipping_address = array();
			// get shipping address
			if (isset($_POST['ship_to_different_address']) && $_POST['ship_to_different_address'] == 'on') {
				$shipping_address = array(
					'shipping_first_name' => sanitize_text_field(isset($sa['shipping_first_name']) ? $sa['shipping_first_name'] : null),
					'shipping_last_name' => sanitize_text_field(isset($sa['shipping_last_name']) ? $sa['shipping_last_name'] : null),
					'shipping_email' => sanitize_email(isset($sa['shipping_email']) ? $sa['shipping_email'] : null),
					'shipping_phone' => sanitize_text_field(isset($sa['shipping_phone']) ? $sa['shipping_phone'] : null),
					'shipping_company' => sanitize_text_field(isset($sa['shipping_company']) ? $sa['shipping_company'] : null),
					'shipping_country' => sanitize_text_field(isset($sa['shipping_country']) ? $sa['shipping_country'] : null),
					'shipping_street_address' => sanitize_text_field(isset($sa['shipping_street_address']) ? $sa['shipping_street_address'] : null),
					'shipping_city' => sanitize_text_field(isset($sa['shipping_city']) ? $sa['shipping_city'] : null),
					'shipping_state' => sanitize_text_field(isset($sa['shipping_state']) ? $sa['shipping_state'] : null),
					'shipping_zip' => sanitize_text_field(isset($sa['shipping_zip']) ? $sa['shipping_zip'] : null),
				);
			} else {
				/**
				 * Copy the billing address to shipping address
				 * but we need to replace keys billing to shipping
				 */
				foreach ($billing_address as $key => $value) {
					$shipping_key = str_replace('billing_', 'shipping_', $key);
					$shipping_address[$shipping_key] = $value;
				}
			}

			if(isset( $_POST['cart'] )){
				$cart = json_decode(wp_kses_post(base64_decode( $_POST['cart'] )), true );
			}else{
				$cart = null;
				if ( Cart::is_empty() ) {
					wp_die(__('Your cart have no item to checkout', 'commercioo'), __('Error!', 'commercioo'), array(
						'back_link' => false,
                        'link_url'=>comm_get_shopping_uri(),
                        'link_text'=>__('Go to Shop now',"commercioo")
					));
				}
			}

			// order_items
			$order_items = array();
			// normalize cart data structure as REST API needed
			foreach ( Cart::get_items( $cart ) as $product_id => $item ) {
				$order_items[] = array(
					'product_id' => intval( $product_id ),
					'item_order_qty' => intval( $item['qty'] ),
				);
				$get_stock_status = get_post_meta(intval( $product_id ), "_stock_status", true);
                if($get_stock_status == 'outofstock'){
                    wp_die(get_the_title(intval( $product_id )).'. '. __('This item is out of stock', 'commercioo'), __('Error!', 'commercioo'), array(
						'back_link' => true,
					));
                }
			}

			// get current user_id
			if (!$user_id = get_current_user_id()) {
				if (function_exists('comm_do_auto_register')) {
					$user_id = comm_do_auto_register($ba, $sa, 'comm_pending');
				} else {
					wp_die(
						__('Sorry, but you must be logged-in to create an order', 'commercioo'),
						__('Error!', 'commercioo'), array(
							'back_link' => true,
						)
					);
				}
			}
            if($_POST['payment_method']=="paypal" && sanitize_text_field($comm_options['currency']) =="IDR"){
                wp_die(
                    __('Sorry, your current currency IDR does not support to process Paypal', 'commercioo'),
                    __('Error!', 'commercioo'), array(
                        'back_link' => true,
                    )
                );
            }
            $customers_id = sanitize_text_field(isset($_POST['customers_id']) ? intval($_POST['customers_id']) : null);
			$customer = new \Commercioo\Models\Customer($user_id,$customers_id);
			$customer_id = $customer->set_customer($billing_address);
			// set order data to save
            $payment_method = sanitize_text_field(isset($_POST['payment_method']) ? $_POST['payment_method'] : 'bacs');
            $payment_method_for_name = $payment_method;
            $post_title_name ="bacs";
            if (strpos($payment_method, 'TRIPAY') !== false) {
                $payment_method_for_name = str_replace("TRIPAY_", "", $payment_method);
                $post_title_name ="tripay";
            }
            $order_data = apply_filters('commercioo_order_data_to_submit', array(
				'user_id' => $user_id,
				'status' => 'comm_pending',
				'billing_address' => $billing_address,
				'shipping_address' => $shipping_address,
				'payment_method' => $payment_method,
				'payment_method_name' => sanitize_text_field(isset($_POST['payment_method_name'][$payment_method_for_name]) ? $_POST['payment_method_name'][$payment_method_for_name] : 'bacs'),
				'order_notes' => sanitize_textarea_field(isset($_POST['order_notes']) ? $_POST['order_notes'] : ''),
				'order_items' => $order_items,
				'order_currency' => $comm_options['currency'],
			));

            $arg_order ['post_author']=$user_id;
            if($payment_method=="paypal"){
                $post_title_name ="paypal";
            }
            $arg_order ['post_title']=sprintf("comm_order_{$post_title_name}_%s", uniqid());
            $arg_order ['post_excerpt']=$order_data['order_notes'];
            $arg_order ['post_status']=$order_data['status'];
            $arg_order ['post_type']='comm_order';

			if(isset($_POST['order_id']) && !empty($_POST['order_id'])){
				$order_id = sanitize_text_field(absint($_POST['order_id']));
                $arg_order ['ID']=$order_id;
				wp_update_post($arg_order);
			}else{
				// create order
				$order_id = wp_insert_post($arg_order);
			}
			// bail out on error
			if (is_wp_error($order_id)) {
				$message = $order_id->get_error_message();
				wp_die(sprintf(__('An error occurred: %s', 'commercioo'), $message), __('Error!', 'commercioo'), array(
					'back_link' => true,
				));
			}
            // General parameter value for update into post meta
            $args = array(
                '_user_id'=>intval($order_data['user_id']),
                '_customer_id'=>intval($customer_id),
                '_billing_address'=>array_map('esc_html', $order_data['billing_address']),
                '_shipping_address'=>array_map('esc_html', $order_data['shipping_address']),
                '_payment_method'=>sanitize_text_field($order_data['payment_method']),
                '_payment_method_name'=>sanitize_text_field($order_data['payment_method_name']),
                '_order_currency'=>sanitize_text_field($order_data['order_currency']),
                '_order_notes'=>sanitize_textarea_field($order_data['order_notes']),
                '_order_key'=>sanitize_text_field(\Commercioo\Helper::commercioo_generate_order_key()),
                '_order_total'=>apply_filters( 'comm_order_total_price', \Commercioo\Cart::get_total(), $order_id )
            );


            // Process update into post meta
            // already available: discount, fee and unique number
            do_action("commercioo_update_post_meta",$args,$order_id);

			// set order items
			$comm_order = \commercioo\admin\Comm_Order::get_instance();
			$comm_order->set_comm_order_items($order_id, $order_data['order_items']);

			// update user's profile
			$comm_users = \commercioo\admin\Comm_Users::get_instance();

			// update the shipping address just if it has been defined
			if (isset($_POST['ship_to_different_address']) && $_POST['ship_to_different_address'] == 'on') {
				$comm_users->update_users_billing_and_shipping_address(
					$order_data['user_id'],
					$order_data['billing_address'],
					$order_data['shipping_address']
				);
			}
			else {
				$comm_users->update_users_billing_and_shipping_address(
					$order_data['user_id'],
					$order_data['billing_address'],
					null
				);
			}

			// action after create order
			do_action('commercioo_after_creating_order', $order_id, $order_data['status']);

			// redirect after order
            $order              = new \Commercioo\Models\Order( $order_id );
            if($payment_method=="paypal"){
                $return_url = \Commercioo\Helper::commercioo_get_endpoint_url( 'commercioo-payal', $order_id, comm_get_thank_you_uri() );
                $return_url  = add_query_arg( 'key', $order->get_order_key(), $return_url );

                $cancel_return_url = \Commercioo\Helper::commercioo_get_endpoint_url( 'commercioo-payal-failed', $order_id, comm_get_thank_you_uri() );
                $cancel_return_url  = add_query_arg( 'key', $order->get_order_key(), $cancel_return_url );

                $purchase_data['order_id'] = $order_id;
                foreach ( Cart::get_items( $cart ) as $product_id => $item ) {
                    $purchase_data['product'][$product_id] = array(
                        'name' => sanitize_text_field( $item['name'] ),
                        'qty' => intval( $item['qty'] ),
                        'price' => intval( $item['price'] ),
                    );
                }
                $purchase_data['cart'] = Cart::get_carts();
                $purchase_data['currency_code'] = $comm_options['currency'];

                $purchase_data['redirect_thank_you_page'] = esc_url($return_url);
                $purchase_data['cancel_return'] = esc_url($cancel_return_url);

                $purchase_data['invoice'] = $order->get_order_key();
                $purchase_data['frequency'] = 1;
                $purchase_data['member'] = [
                    'user_id' => $order_data['user_id'],
                    'first_name' => isset($billing_address['billing_first_name']) ? $billing_address['billing_first_name'] : '',
                    'last_name' => '',
                    'email' => isset($billing_address['billing_email']) ? $billing_address['billing_email'] : '',
                ];
                do_action("commercioo/process/{$payment_method}",$order_id,$purchase_data);
            }else{
                $return_url = \Commercioo\Helper::commercioo_get_endpoint_url( 'commercioo-order-received', $order_id, comm_get_thank_you_uri() );
                $return_url = $order_received_url = add_query_arg( 'key', $order->get_order_key(), $return_url );
                $return_url = apply_filters('commercioo_redirect_url_after_order', $return_url, $order_id);
                wp_redirect($return_url);
                exit;
            }
		}

		/**
		 * Mainly used in `do_checkout` method
		 */
		private static function validate_checkout_data() {
			global $comm_options;

			// args
			$error_messages = array();
			$has_shipping_address = sanitize_text_field(isset($_POST['ship_to_different_address']) && $_POST['ship_to_different_address'] == 'on');
			$billing_fields_status = array('last_name', 'company', 'country', 'street_address', 'city', 'state', 'zip');

			/**
			 * Billing and shipping addresses
			 * ba as billing_address
			 * sa as shipping_address
			 * opt_ba as $comm_options['billing_address']
			 */
			$ba = array_map("sanitize_text_field",isset($_POST['billing_address']) && is_array($_POST['billing_address']) ? $_POST['billing_address'] : array());
			$sa = array_map("sanitize_text_field",isset($_POST['shipping_address']) && is_array($_POST['shipping_address']) ? $_POST['shipping_address'] : array());
			$opt_ba = array_map("sanitize_text_field",isset($comm_options['billing_address']) && is_array($comm_options['billing_address']) ? $comm_options['billing_address'] : array());

			// validate first_name
			if (
				!isset($ba['billing_first_name']) || strlen(trim($ba['billing_first_name'])) < 2
				|| ($has_shipping_address && (!isset($sa['shipping_first_name']) || strlen(trim($sa['shipping_first_name'])) < 2))
			) {
				$error_messages[] = __('Minimum "First Name" length is 2', 'commercioo');
			}

			// validate email
			if (
				!isset($ba['billing_email']) || !is_email($ba['billing_email'])
				|| ($has_shipping_address && (!isset($sa['shipping_email']) || !is_email($sa['shipping_email'])))
			) {
				$error_messages[] = __('Invalid email address', 'commercioo');
			}

			// validate phone number
			if (
				!isset($ba['billing_phone']) || strlen(trim($ba['billing_phone'])) < 5
				|| ($has_shipping_address && (!isset($sa['shipping_phone']) || strlen(trim($sa['shipping_phone'])) < 5))
			) {
				$error_messages[] = __('Minimum "Phone Number" length is 5', 'commercioo');
			}

			// validate payment method
			if ( ! isset( $_POST['payment_method'] ) || $_POST['payment_method'] == null ) {
				$error_messages[] = __('Invalid payment method', 'commercioo');
			}

			// some fields has their `required` status
			foreach ($billing_fields_status as $field) {
				if (
					( ! isset($opt_ba["billing_{$field}_visibility"]) || $opt_ba["billing_{$field}_visibility"] == 'required' )
					&& (
						!isset($ba["billing_{$field}"]) || strlen(trim($ba["billing_{$field}"])) == 0
						|| ($has_shipping_address && (!isset($sa["shipping_{$field}"]) || strlen(trim($sa["shipping_{$field}"])) == 0))
					)
				) {
					$error_messages[] = sprintf(__('"%s" is required', 'commercioo'), $opt_ba["billing_{$field}"]);
				}
			}

			// bail out for any errors found
			if (count($error_messages) > 0) {
				$wp_die_html = '<h1>' . esc_html__('Errors Found!', 'commercioo') . '</h1>';
				$wp_die_html .= '<p>' . esc_html__('Unfortunately, there are some errors occurred:', 'commercioo') . '</p>';
				$wp_die_html .= '<ul>';

				foreach ($error_messages as $message) {
					$wp_die_html .= '<li>' . esc_html($message) . '</li>';
				}

				$wp_die_html .= '</ul>';

				wp_die($wp_die_html, __('Error!', 'commercioo'), array(
					'back_link' => true,
				));
			}

			return true;
		}

		/**
		 * Sort fields based on priority.
		 *
		 * @param  array $x Field.
		 * @param  array $y Field.
		 * @return int      Diff.
		 */
		private function sort_field_by_priority( $x, $y ) {
			return ( isset( $x['priority'] ) ? $x['priority'] : 50 ) - ( isset( $y['priority'] ) ? $y['priority'] : 50 );
		}
        /**
         * Save datas into post_meta table.
         *
         * @param  array $args value with columns key.
         * @param int  $order_id  order_id.
         */
		public function commercioo_update_post_meta($args=array(),$order_id=0){
           if($args){
               foreach ($args as $key => $v){
                   update_post_meta($order_id, $key, $v);
               }
           }
        }
	}
}